summaryrefslogtreecommitdiff
path: root/sys/arch/vax/include
diff options
context:
space:
mode:
authorTheo de Raadt <deraadt@cvs.openbsd.org>2004-07-07 23:10:47 +0000
committerTheo de Raadt <deraadt@cvs.openbsd.org>2004-07-07 23:10:47 +0000
commit82eede488a736053ee53d7963df114bb8c4f8e80 (patch)
tree34094ffb91e7cfe3131630966dc0a4deaf9bdd9a /sys/arch/vax/include
parentf6adcfa1e8fa253c177874131f7bd165bcbe0fd1 (diff)
new-style interrupt counters. based on initial work by hugh. ok miod
Diffstat (limited to 'sys/arch/vax/include')
-rw-r--r--sys/arch/vax/include/cpu.h3
-rw-r--r--sys/arch/vax/include/scb.h10
-rw-r--r--sys/arch/vax/include/types.h3
-rw-r--r--sys/arch/vax/include/vsbus.h4
4 files changed, 11 insertions, 9 deletions
diff --git a/sys/arch/vax/include/cpu.h b/sys/arch/vax/include/cpu.h
index a0df493ff3e..6a536162973 100644
--- a/sys/arch/vax/include/cpu.h
+++ b/sys/arch/vax/include/cpu.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: cpu.h,v 1.16 2004/06/13 21:49:21 niklas Exp $ */
+/* $OpenBSD: cpu.h,v 1.17 2004/07/07 23:10:45 deraadt Exp $ */
/* $NetBSD: cpu.h,v 1.41 1999/10/21 20:01:36 ragge Exp $ */
/*
@@ -37,6 +37,7 @@
#include <sys/cdefs.h>
#include <sys/device.h>
+#include <sys/evcount.h>
#include <machine/mtpr.h>
#include <machine/pte.h>
diff --git a/sys/arch/vax/include/types.h b/sys/arch/vax/include/types.h
index b465a925475..8d16a7246b8 100644
--- a/sys/arch/vax/include/types.h
+++ b/sys/arch/vax/include/types.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: types.h,v 1.12 2003/06/02 23:27:57 millert Exp $ */
+/* $OpenBSD: types.h,v 1.13 2004/07/07 23:10:45 deraadt Exp $ */
/* $NetBSD: types.h,v 1.14 1998/08/13 02:10:49 eeh Exp $ */
/*-
@@ -74,5 +74,6 @@ typedef unsigned long long u_int64_t;
typedef int32_t register_t;
#define __HAVE_DEVICE_REGISTER
+#define __HAVE_EVCOUNT
#endif /* _MACHTYPES_H_ */
diff --git a/sys/arch/vax/include/vsbus.h b/sys/arch/vax/include/vsbus.h
index 91d58a21ca1..2a05affaace 100644
--- a/sys/arch/vax/include/vsbus.h
+++ b/sys/arch/vax/include/vsbus.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: vsbus.h,v 1.7 2002/03/14 01:26:48 millert Exp $ */
+/* $OpenBSD: vsbus.h,v 1.8 2004/07/07 23:10:45 deraadt Exp $ */
/* $NetBSD: vsbus.h,v 1.13 2000/06/25 16:00:46 ragge Exp $ */
/*
* Copyright (c) 1996 Ludd, University of Lule}, Sweden.
@@ -92,7 +92,7 @@ struct vsbus_attach_args {
void *va_vecarg; /* Interrupt routine argument */
short va_br; /* Interrupt level */
- short va_cvec; /* Interrupt vector address */
+ int va_cvec; /* Interrupt vector address */
u_char va_maskno; /* Interrupt vector in mask */
vaddr_t va_dmaaddr; /* DMA area address */
vsize_t va_dmasize; /* DMA area size */
diff --git a/sys/arch/vax/include/scb.h b/sys/arch/vax/include/scb.h
index c870085725f..82b09d6ec22 100644
--- a/sys/arch/vax/include/scb.h
+++ b/sys/arch/vax/include/scb.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: scb.h,v 1.6 2001/08/25 13:33:36 hugh Exp $ */
+/* $OpenBSD: scb.h,v 1.7 2004/07/07 23:10:45 deraadt Exp $ */
/* $NetBSD: scb.h,v 1.11 2000/07/10 09:14:34 ragge Exp $ */
/*
@@ -113,7 +113,7 @@ struct scb {
/*
* This struct is used when setting up interrupt vectors dynamically.
* It put a opaque 32 bit quanity on the stack and also has a placeholder
* for evcnt structure.
*/
struct ivec_dsp {
char pushr; /* pushr */
@@ -123,19 +123,19 @@ struct ivec_dsp {
long displacement;
void (*hoppaddr)(void *);
void *pushlarg;
- struct evcnt *ev;
+ struct evcount *ev;
};
#ifdef _KERNEL
extern const struct ivec_dsp idsptch;
extern struct scb *scb;
extern struct ivec_dsp *scb_vec;
-extern struct evcnt devipl_intrcnts[4]; /* IPL 2[0123] */
+extern struct evcount devipl_intrcnts[4]; /* IPL 2[0123] */
extern paddr_t scb_init (paddr_t);
extern int scb_vecref (int *, int *);
extern void scb_fake (int, int);
-extern void scb_vecalloc (int, void(*)(void *), void *, int, struct evcnt *);
+extern void scb_vecalloc (int, void(*)(void *), void *, int, struct evcount *);
#endif /* _KERNEL */
#endif /* _VAX_SCB_H */
@@ -113,7 +113,7 @@ struct scb {
* This struct is used when setting up interrupt vectors dynamically.
* It put a opaque 32 bit quanity on the stack and also has a placeholder
- * for evcnt structure.
+ * for evcount structure.
*/
struct ivec_dsp {